@@ -1,14 +1,15 @@
 package Opsview::REST::APICaller;
 {
-  $Opsview::REST::APICaller::VERSION = '0.010';
+  $Opsview::REST::APICaller::VERSION = '0.011';
 }
 
 use Moo::Role;
 
 use Carp;
 
+use Try::Tiny;
 use JSON::XS ();
-use HTTP::Tiny;
+use HTTP::Tiny 0.014;
 
 has ua => (
     is      => 'ro',
@@ -76,15 +77,23 @@ sub put {
 
 sub _errmsg {
     my ($self, $r) = @_;
-    my $cont; $cont = $self->json->decode($r->{content})
-        if $r->{content};
+    my $exc = {
+        status => $r->{status},
+        reason => $r->{reason},
+    };
 
-    return Opsview::REST::Exception->new(
-        status  => $r->{status},
-        reason  => $r->{reason},
-        message => $cont ? $cont->{message} : undef,
-        detail  => $cont ? $cont->{detail}  : undef,
-    );
+    if ($r->{content}) {
+        try {
+            my $resp;
+            $resp = $self->json->decode($r->{content});
+            $exc->{message} = $resp->{message} || undef;
+            $exc->{detail}  = $resp->{detail}  || undef;
+        } catch {
+            $exc->{message} = $r->{content};
+        };
+    }
+
+    return Opsview::REST::Exception->new($exc);
 }
 
 1;
